#
# spec file for package 4ti2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           4ti2
Version:        1.6.10
Release:        1.5
Summary:        Package for algebraic, geometric and combinatorial problems on linear spaces
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://4ti2.github.io/

Source:         https://github.com/4ti2/4ti2/releases/download/Release_1_6_10/4ti2-1.6.10.tar.gz
Patch2:         4ti2-handle-prefix.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 4.3
BuildRequires:  glpk-devel >= 4.52
BuildRequires:  gmp-devel >= 4.1.4

%description
4ti2 is a collection of programs that compute and solve algebraic,
geometric and combinational problems on linear spaces.

%package -n lib4ti2-0
Summary:        Library for computation of Gröbner bases with 4ti2
Group:          System/Libraries

%description -n lib4ti2-0
This package contains the 4ti2 program library, which comes in three
flavors:
- 32-bit precision integers
- 64-bit precision integers
- arbitrary precision integer support through use of GNU MP

%package -n libzsolve0
Summary:        Library for solving linear systems over integers for 4ti2
Group:          System/Libraries

%description -n libzsolve0
This package contains the 4ti2 library for solving systems linear systems over
integers (\mathbb{Z}).

%package devel
Summary:        Development files for 4ti2
Group:          Development/Libraries/C and C++
Requires:       lib4ti2-0 = %version
Requires:       libzsolve0 = %version

%description devel
This subpackage contains the include files and library links for
developing against 4ti2's libraries.

%prep
%autosetup -p1

%build
%configure --enable-shared --disable-static \
	--includedir="%_includedir/%name" --docdir="%_docdir/%name"
%make_build

%install
%make_install
b="%buildroot"
rm -f "$b/%_libdir"/*.la
mkdir -p "$b/%_bindir" "$b/%_libexecdir/%name"
mv "$b/%_bindir"/* "$b/%_libexecdir/%name/"
pushd "$b/%_libexecdir/%name"
for i in *; do
	ln -s "%_libexecdir/%name/$i" "$b/%_bindir/4ti2_$i"
done
%fdupes -s %buildroot/%_prefix

%post   -n lib4ti2-0 -p /sbin/ldconfig
%postun -n lib4ti2-0 -p /sbin/ldconfig
%post   -n libzsolve0 -p /sbin/ldconfig
%postun -n libzsolve0 -p /sbin/ldconfig

%files
%license COPYING
%doc doc/[34a-z]*
%_bindir/4ti2*
%_libexecdir/%name/

%files -n lib4ti2-0
%_libdir/lib4ti2gmp.so.0*
%_libdir/lib4ti2int32.so.0*
%_libdir/lib4ti2int64.so.0*
%_libdir/lib4ti2common.so.0*
%_libdir/lib4ti2util.so.0*

%files -n libzsolve0
%_libdir/libzsolve.so.0*

%files devel
%_includedir/%name/
%_libdir/lib*.so

%changelog
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.10
  * Fix memory leak in permuteListVector
- Delete 0001-build-resolve-missing-includes-showing-on-gcc-13.patch,
  4ti2-docdir.diff
* Mon Mar 27 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-resolve-missing-includes-showing-on-gcc-13.patch
* Thu Jul  1 2021 Jan Engelhardt <jengelh@inai.de>
- Run fdupes to eliminate script copies.
* Thu Jul  1 2021 Alois Wohlschlager <alois1@gmx-topmail.de>
- Add patch 4ti2-handle-prefix.patch to handle the downstream
  4ti2_ executable prefix in wrapper scripts.
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile.
* Fri Oct 19 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.6.9
  * Fix out of bounds vector access in circuits.
- Remove 4ti2-missing-libs.diff (not needed)
* Fri Mar 11 2016 jengelh@inai.de
- Update to new upstream release 1.6.7
  * Add tests for "walk -p arb" to testsuite
  * Fix division-by-zero in "walk -p arb" for testcase 344
* Mon Oct 26 2015 p.drouand@gmail.com
- Update to version 1.6.6
  * Fix segfault in graver when a matrix with trivial kernel is input
    (testcase graver/trivial-kernel).
- Changes from version 1.6.5
  * Fix build failure with gcc 4.9.2.
- Changes from version 1.6.4
  * Improved error checking while reading zsolve input files.
  * The PDF manual has been updated to include a reference to commands
    and their options and a reference to the API.  The command
    reference on www.4ti2.de has also been updated.
  * Better option handling.  Make long options available in non-GNU
    platforms such as Mac OS X.  All commands now support the
    standard --help and --version options.
  * Minor fix to the test suite.
- Changes from version 1.6.3
  * The manual has been updated.
  * Minor build fixes.
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 1.6.2
  * Support for newer libglpk API "glp_"
  (which replaced the "lpx_" API)
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 1.6
  * Restore the functionality of "hilbert" to accept "rel" files
  * When the cone is not pointed, "hilbert" now outputs a "zfree" file,
  containing a lattice basis, in addition to the "hil" file.
- Remove 4ti2-gcc.diff, 4ti2-nonvoid-return.diff, 4ti2-libtool.diff
  (merged upstream)
* Wed Apr 17 2013 jengelh@inai.de
- Combine shared library packages lib4ti2{gmp0,int32-0,int64-0}
  as they are updated in lockstep
* Fri Dec  7 2012 jengelh@inai.de
- Initial package (version 1.3.2) for build.opensuse.org
- Add 4ti2-missing-libs.diff, 4ti2-docdir.diff to address build
  problems
